@@ -76,12 +76,12 @@ where
                     .as_slice();
                 DataValue::V128(buffer.try_into().expect("a 16-byte data buffer"))
             }
-            InstructionData::Shuffle { mask, .. } => {
+            InstructionData::Shuffle { imm, .. } => {
                 let mask = state
                     .get_current_function()
                     .dfg
                     .immediates
-                    .get(mask)
+                    .get(imm)
                     .unwrap()
                     .as_slice();
                 DataValue::V128(mask.try_into().expect("a 16-byte vector mask"))
@@ -448,6 +448,7 @@ where
             assign(Value::or(mask_a, mask_b)?)
         }
         Opcode::Copy => assign(arg(0)?),
+        Opcode::IfcmpSp => unimplemented!("IfcmpSp"),
         Opcode::Icmp => assign(icmp(
             ctrl_ty,
             inst.cond_code().unwrap(),
